@@ -65,7 +65,6 @@ class PayrollFlow(Flow):
             'current_year',
             'current_month',
             'employee',
-            'employer'
         ]).Permission(auto_create=True).Available(lambda user: user.pk is not None).Next(this.fill_timesheet)
     )
 
@@ -74,8 +73,45 @@ class PayrollFlow(Flow):
             'submitted'
         ]).Permission(auto_create=True).Next(this.fill_revenue)
     )
+    fill_timesheet.short_description = _('Jelenléti ív kitöltése')
 
     fill_revenue = (
+        View(UpdateProcessView, fields=[
+            'submitted'
+        ]).Permission(auto_create=True).Next(this.fill_non_monetary)
+    )
+
+    fill_non_monetary = (
+        View(UpdateProcessView, fields=[
+            'submitted'
+        ]).Permission(auto_create=True).Next(this.fill_contributions_of_employee)
+    )
+
+    fill_contributions_of_employee = (
+        View(UpdateProcessView, fields=[
+            'submitted'
+        ]).Permission(auto_create=True).Next(this.fill_contributions_of_employer)
+    )
+
+    fill_contributions_of_employer = (
+        View(UpdateProcessView, fields=[
+            'submitted'
+        ]).Permission(auto_create=True).Next(this.fill_tax)
+    )
+
+    fill_tax = (
+        View(UpdateProcessView, fields=[
+            'submitted'
+        ]).Permission(auto_create=True).Next(this.fill_other_taxes)
+    )
+
+    fill_other_taxes = (
+        View(UpdateProcessView, fields=[
+            'submitted'
+        ]).Permission(auto_create=True).Next(this.fill_blockings)
+    )
+
+    fill_blockings = (
         View(UpdateProcessView, fields=[
             'submitted'
         ]).Permission(auto_create=True).Next(this.payroll)
