@@ -167,7 +167,6 @@ class AbsenseStatistic(models.Model):
     def close(self):
         self.value = self.calculate
 
-
 class Salary(IntervalMixin, models.Model):
 
     class Meta:
@@ -304,6 +303,15 @@ class RevenueItem(models.Model):
         default=0
     )
 
+class Dividend(mdm.IntervalMixin, models.Model):
+    """
+    Osztalék
+    """
+    class Meta:
+        db_table = 'dividends'
+        verbose_name = _('osztalék')
+        verbose_name_plural = _('osztalékok')
+
 
 
 
